==> flowable-bpmn-converter-6.7.0-sources.jar: org/flowable/bpmn/converter/ThrowEventXMLConverter.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.bpmn.converter;

import java.util.HashMap;
import java.util.Map;

import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import org.flowable.bpmn.converter.child.BaseChildElementParser;
import org.flowable.bpmn.converter.child.OutParameterParser;
import org.flowable.bpmn.converter.util.BpmnXMLUtil;
import org.flowable.bpmn.model.BaseElement;
import org.flowable.bpmn.model.BpmnModel;
import org.flowable.bpmn.model.ThrowEvent;

/**
 * @author Tijs Rademakers
 */
public class ThrowEventXMLConverter extends BaseBpmnXMLConverter {
    
    protected Map<String, BaseChildElementParser> childParserMap = new HashMap<>();

    public ThrowEventXMLConverter() {
        OutParameterParser outParameterParser = new OutParameterParser();
        childParserMap.put(outParameterParser.getElementName(), outParameterParser);
    }

    @Override
    public Class<? extends BaseElement> getBpmnElementType() {
        return ThrowEvent.class;
    }

    @Override
    protected String getXMLElementName() {
        return ELEMENT_EVENT_THROW;
    }

    @Override
    protected BaseElement convertXMLToElement(XMLStreamReader xtr, BpmnModel model) throws Exception {
        ThrowEvent throwEvent = new ThrowEvent();
        BpmnXMLUtil.addXMLLocation(throwEvent, xtr);
        parseChildElements(getXMLElementName(), throwEvent, childParserMap, model, xtr);
        return throwEvent;
    }

    @Override
    protected void writeAdditionalAttributes(BaseElement element, BpmnModel model, XMLStreamWriter xtw) throws Exception {
    }

    @Override
    protected void writeAdditionalChildElements(BaseElement element, BpmnModel model, XMLStreamWriter xtw) throws Exception {
        ThrowEvent throwEvent = (ThrowEvent) element;
        writeEventDefinitions(throwEvent, throwEvent.getEventDefinitions(), model, xtw);
    }
}

==> flowable-bpmn-converter-7.0.0-sources.jar: org/flowable/bpmn/converter/ThrowEventXMLConverter.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.bpmn.converter;

import java.util.HashMap;
import java.util.Map;

import javax.xml.stream.XMLStreamReader;
import javax.xml.stream.XMLStreamWriter;

import org.flowable.bpmn.converter.child.BaseChildElementParser;
import org.flowable.bpmn.converter.child.OutParameterParser;
import org.flowable.bpmn.converter.util.BpmnXMLUtil;
import org.flowable.bpmn.model.BaseElement;
import org.flowable.bpmn.model.BpmnModel;
import org.flowable.bpmn.model.ThrowEvent;

/**
 * @author Tijs Rademakers
 */
public class ThrowEventXMLConverter extends BaseBpmnXMLConverter {
    
    protected Map<String, BaseChildElementParser> childParserMap = new HashMap<>();

    public ThrowEventXMLConverter() {
        OutParameterParser outParameterParser = new OutParameterParser();
        childParserMap.put(outParameterParser.getElementName(), outParameterParser);
    }

    @Override
    public Class<? extends BaseElement> getBpmnElementType() {
        return ThrowEvent.class;
    }

    @Override
    protected String getXMLElementName() {
        return ELEMENT_EVENT_THROW;
    }

    @Override
    @SuppressWarnings("unchecked")
    protected BaseElement convertXMLToElement(XMLStreamReader xtr, BpmnModel model) throws Exception {
        ThrowEvent throwEvent = new ThrowEvent();
        BpmnXMLUtil.addXMLLocation(throwEvent, xtr);
        
        BpmnXMLUtil.addCustomAttributes(xtr, throwEvent, defaultElementAttributes, defaultActivityAttributes);
        
        parseChildElements(getXMLElementName(), throwEvent, childParserMap, model, xtr);
        return throwEvent;
    }

    @Override
    protected void writeAdditionalAttributes(BaseElement element, BpmnModel model, XMLStreamWriter xtw) throws Exception {
    }

    @Override
    protected void writeAdditionalChildElements(BaseElement element, BpmnModel model, XMLStreamWriter xtw) throws Exception {
        ThrowEvent throwEvent = (ThrowEvent) element;
        writeEventDefinitions(throwEvent, throwEvent.getEventDefinitions(), model, xtw);
    }
}
